# NEST Firmware - Arduino Version (Prototipo Wearable)

Este repositorio contiene el firmware para el proyecto **NEST (Non-intrusive dEviceS for Telemedicine)**, desarrollado para un **prototipo wearable** en la plataforma **Arduino**. El firmware controla el monitoreo de **frecuencia cardíaca (BPM)** mediante el sensor **MAX30102** y el microcontrolador **nRF52840** con **Bluetooth Low Energy (BLE)** integrado. Este repositorio incluye el bootloader y las bibliotecas necesarias para compilar y programar el código.

## Estructura del repositorio

- **/bootloader**: Archivos del bootloader para el nRF52840.
- **/firmware**: Código fuente del firmware desarrollado en Arduino.
- **/libraries**: Biblioteca necesaria, como **Ucglib.h**, utilizada para controlar la pantalla TFT.

## Requisitos para Programar en Arduino

### Paso 1: Instalar Arduino Core para nRF52840

1. **Descargar e instalar Arduino IDE** (al menos v1.6.12): [Arduino IDE](https://www.arduino.cc/en/software).
2. Iniciar el Arduino IDE y entrar a las **Preferencias**.
3. En **Additional Board Manager URLs**, agregar:  
   `https://adafruit.github.io/arduino-board-index/package_adafruit_index.json`
4. Reiniciar el Arduino IDE.
5. Ir a **Herramientas > Placa > Gestor de Placas** y buscar "Adafruit nRF52" e instalar **Adafruit nRF52 by Adafruit**.
6. Una vez instalado, seleccionar **Adafruit Feather nRF52840 Express** desde **Herramientas > Placa** para configurar el sistema.

### Paso 2: Cargar el Bootloader con J-Link

1. Instalar el **Segger JLink Software and Documentation Pack** y **Nordic nRF5x Command Line Tools**.
2. Asegurarse de que puedes ejecutar `nrfjprog` desde tu terminal.
3. Conectar el **J-Link** a la placa.
4. Abrir el Arduino IDE y seleccionar:
   - **Herramientas > Placa > Adafruit Feather nRF52840 Express**
   - **Herramientas > Programador > J-Link for Feather52**
   - **Herramientas > Grabar Bootloader** para cargar el bootloader en la placa.

### Paso 3: Programar el Bootloader manualmente con nrfjprog

Si prefieres cargar el bootloader manualmente, sigue estos pasos:

1. Ejecuta los siguientes comandos en tu terminal para borrar la memoria y cargar el bootloader:

   ```bash
   nrfjprog -e -f nrf52
   nrfjprog --program bin/bootloader/feather_nrf52840_bootloader.hex -f nrf52
   nrfjprog --reset -f nrf52

## Descripción del Firmware

El firmware permite las siguientes funcionalidades:
- Monitoreo de **BPM** y **SpO2** utilizando el sensor **MAX30102**.
- Interacción con el usuario a través de una pantalla **TFT** controlada con la biblioteca **Ucglib.h**.
- Transmisión de datos a una base de datos remota utilizando **Bluetooth Low Energy (BLE)**.
- Gestión de encuestas de dolor y recordatorios de medicación.


